Label
=========================

.. currentmodule:: enaml.widgets.label

.. autoclass:: Label


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_label.QtLabel
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_label.QtLabel

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_label.WXLabel
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_label.WXLabel
